diff --git a/src/dd.c b/src/dd.c
index c98e578..03b0c54 100644
--- a/src/dd.c
+++ b/src/dd.c
@@ -1552,11 +1552,15 @@ skip (int fdesc, char const *file, uintmax_t records, size_t blocksize,
            struct stat st;
            if (fstat (STDIN_FILENO, &st) != 0)
              error (EXIT_FAILURE, errno, _("cannot fstat %s"), quote (file));
-           if (usable_st_size (&st) && st.st_size < input_offset + offset)
+           if (usable_st_size (&st) && st.st_size > 0 && st.st_size < input_offset + offset)
              {
-               /* When skipping past EOF, return the number of _full_ blocks
-                * that are not skipped, and set offset to EOF, so the caller
-                * can determine the requested skip was not satisfied.  */
+               /* For file with size > 0 (there's no way to tell the difference
+               * between a special file (really STDIN or something like
+               * /proc/self/mem) because the fdesc has been reopened as
+               * STDIN_FILENO)
+               * and when skipping past EOF, return the number of _full_ blocks
+               * that are not skipped, and set offset to EOF, so the caller
+               * can determine the requested skip was not satisfied.  */
                records = ( offset - st.st_size ) / blocksize;
                offset = st.st_size - input_offset;
              }
